if [ -f /etc/xinetd.d/chargen-dgram ] && cmp -s /etc/defaults/etc/xinetd.d/chargen-dgram /etc/xinetd.d/chargen-dgram
then
    rm /etc/xinetd.d/chargen-dgram
fi

if [ -f /etc/xinetd.d/chargen-stream ] && cmp -s /etc/defaults/etc/xinetd.d/chargen-stream /etc/xinetd.d/chargen-stream
then
    rm /etc/xinetd.d/chargen-stream
fi

if [ -f /etc/xinetd.d/daytime-dgram ] && cmp -s /etc/defaults/etc/xinetd.d/daytime-dgram /etc/xinetd.d/daytime-dgram
then
    rm /etc/xinetd.d/daytime-dgram
fi

if [ -f /etc/xinetd.d/daytime-stream ] && cmp -s /etc/defaults/etc/xinetd.d/daytime-stream /etc/xinetd.d/daytime-stream
then
    rm /etc/xinetd.d/daytime-stream
fi

if [ -f /etc/xinetd.d/discard-dgram ] && cmp -s /etc/defaults/etc/xinetd.d/discard-dgram /etc/xinetd.d/discard-dgram
then
    rm /etc/xinetd.d/discard-dgram
fi

if [ -f /etc/xinetd.d/discard-stream ] && cmp -s /etc/defaults/etc/xinetd.d/discard-stream /etc/xinetd.d/discard-stream
then
    rm /etc/xinetd.d/discard-stream
fi

if [ -f /etc/xinetd.d/echo-dgram ] && cmp -s /etc/defaults/etc/xinetd.d/echo-dgram /etc/xinetd.d/echo-dgram
then
    rm /etc/xinetd.d/echo-dgram
fi

if [ -f /etc/xinetd.d/echo-stream ] && cmp -s /etc/defaults/etc/xinetd.d/echo-stream /etc/xinetd.d/echo-stream
then
    rm /etc/xinetd.d/echo-stream
fi

if [ -f /etc/xinetd.d/ftp-sensor ] && cmp -s /etc/defaults/etc/xinetd.d/ftp-sensor /etc/xinetd.d/ftp-sensor
then
    rm /etc/xinetd.d/ftp-sensor
fi

if [ -f /etc/xinetd.d/services ] && cmp -s /etc/defaults/etc/xinetd.d/services /etc/xinetd.d/services
then
    rm /etc/xinetd.d/services
fi

if [ -f /etc/xinetd.d/tcpmux-server ] && cmp -s /etc/defaults/etc/xinetd.d/tcpmux-server /etc/xinetd.d/tcpmux-server
then
    rm /etc/xinetd.d/tcpmux-server
fi

if [ -f /etc/xinetd.d/time-dgram ] && cmp -s /etc/defaults/etc/xinetd.d/time-dgram /etc/xinetd.d/time-dgram
then
    rm /etc/xinetd.d/time-dgram
fi

if [ -f /etc/xinetd.d/time-stream ] && cmp -s /etc/defaults/etc/xinetd.d/time-stream /etc/xinetd.d/time-stream
then
    rm /etc/xinetd.d/time-stream
fi

if [ -f /etc/xinetd.conf ] && cmp -s /etc/defaults/etc/xinetd.conf /etc/xinetd.conf
then
    rm /etc/xinetd.conf
fi

if [ -f /etc/sysconfig/xinetd ] && cmp -s /etc/defaults/etc/sysconfig/xinetd /etc/sysconfig/xinetd
then
    rm /etc/sysconfig/xinetd
fi

